# minimod-opt
A mixed-integer solver that solves optimal intervention allocation across time and space (Port from GAMS)

This python module is designed as a port from GAMS and uses `mip` to do mixed-integer optimization.

Visit [the website](https://minimod-nutrition.github.io/minimod) for more information!
